@@ -36,12 +36,6 @@ G_BEGIN_DECLS
 #define EOG_IS_WRAP_LIST(obj)         (GTK_CHECK_TYPE ((obj), EOG_TYPE_WRAP_LIST))
 #define EOG_IS_WRAP_LIST_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), EOG_TYPE_WRAP_LIST))
 
-typedef enum {
-	EOG_LAYOUT_MODE_VERTICAL,
-	EOG_LAYOUT_MODE_HORIZONTAL,
-	EOG_LAYOUT_MODE_RECTANGLE
-} EogLayoutMode;
-
 typedef struct _EogWrapList EogWrapList;
 typedef struct _EogWrapListPrivate EogWrapListPrivate;
 typedef struct _EogWrapListClass EogWrapListClass;
@@ -70,8 +64,6 @@ void eog_wrap_list_set_model (EogWrapList *wlist, EogCollectionModel *model);
 void eog_wrap_list_set_col_spacing (EogWrapList *wlist, guint spacing);
 void eog_wrap_list_set_row_spacing (EogWrapList *wlist, guint spacing);
 
-void eog_wrap_list_set_layout_mode (EogWrapList *wlist, EogLayoutMode lm);
-
 int eog_wrap_list_get_n_selected (EogWrapList *wlist);
 
 EogImage* eog_wrap_list_get_first_selected_image (EogWrapList *wlist);
